function [alpha, beta, flag, history] = eam_fss_simplex (X, y, max_iter, lambda1, lambda2, rho1, rho2, gamma1, gamma2, varargin)

[m, n] = size(X);
Quite = 1;

%% Input Arguments
if (nargin < 4)
    error ('Not enough arguments.');
end

if (nargin == 4 || isempty(max_iter))
    max_iter = 30;
end

if (nargin < 6 || isempty(lambda1))
    lambda_max = norm(X'*y, 'inf') ;
    lambda1 = 0.1*lambda_max    ; 
end

if (nargin < 7 || isempty(lambda2))
    lambda2 = lambda1; 
end

if (nargin < 8 || isempty(rho1))
    rho1 = 1.0; 
end

if (nargin < 9 || isempty(rho2))
    rho2 = 1.0; 
end

if (nargin < 10 || isempty(gamma1))
    gamma1 = 1.0; 
end

if (nargin < 11 || isempty(gamma2))
    gamma2 = 1.0; 
end


%% Initialization
alpha = ones (m,1);
beta  = ones (n,1);
nnn = 50;

%% Solve problem
for iter = 1:max_iter

    A1 = X (alpha>0,:);
    y1 = y (alpha>0);
    
    [b1, beta, ~] = eam_lasso_lsqr_admm(A1, y1, lambda1, rho1, gamma1);
    %[b1, beta, ~] = eam_lasso_lsqr_admm(diag(alpha) * X, diag(alpha) * y, lambda1, rho1, gamma1);
    %[dumb, idx] = sort(sum(b1.*b1,2),'descend');
    %beta = abs(b1);%zeros(n,1);
    %beta(idx(1:featureNumSelect)) = 1.0;
    
    %B = diag(alpha) * y - diag(alpha) * X * beta;       
    B = y - X * beta;
%    B = bb;
%    for ii = 1:nnn-1
%        B = [B bb];
%    end
    
    % Generate Syntehtic Data
    % nInstances = 50;
    % nVars = 10;
    % X = randn(nInstances,nVars);
    % w = rand(nVars,1).*(rand(nVars,1) > .5);
    % y = X*w + randn(nInstances,1);
    yy = zeros(1,1);%zeros(nnn,1);
    alpha = sqrt(sqrt(abs(1./(B+0.00001))));
    alpha = lambda2*((alpha - min(alpha)) / max(alpha));

    % Set up Objective Function
    funObj = @(w)SquaredError(alpha,B',yy);

    % Set up Simplex Projection Function
    funProj = @(w)projectSimplex(alpha);

    % Solve with PQN
    fprintf('\nComputing optimal linear regression parameters on the simplex...\n');
    alpha = minConf_PQN(funObj,alpha,funProj);



%    [a1, a, ~] = eam_lasso_l2_admm(B', lambda2, rho2, gamma2);
%    [dumb, idx] = sort(sum(a1.*a1,2),'descend');
%    %alpha = abs(a1);%zeros(m,1);
%    alpha = zeros(m,1);
%    alpha(idx(1:sampleNumSelect)) = 1.0;
%    %alpha(idx(sampleNumSelect+1:length(idx))) = 0.0;

    history.objval(iter)  = objective(X, y, lambda1, lambda2, alpha, beta);
    if (~Quite)
        fprintf ('iter = %d\t\tObjective = %.14f\n', iter, history.objval(iter));
    end
    
    if iter > 1 && abs(history.objval(iter) - history.objval(iter-1)) < eps %sum(pre_alpha ~= alpha) <= min_change_samples && sum(pre_beta ~= beta) <= min_change_features
        % Converged
        break;
    end
end

flag = 0;
if iter >= max_iter % ~converged
    flag = 1; % Not converged
end

end


function p = objective(X, y, lambda1, lambda2, alpha, beta)
    %p = ( 1/2*sum(diag(alpha)*(X*beta - y).^2) + lambda2*norm(alpha,1) + lambda1*norm(beta,1) );
    p = ( 1/2*sum(diag(alpha)*(X*beta - y).^2) + lambda1*norm(beta,1));
end